@@ -17,32 +17,32 @@ describe Capybara::Webkit::CookieJar do
 
   describe "#find" do
     it "returns a cookie object" do
-      subject.find("cookie1", "www.facebook.com").domain.should == ".facebook.com"
+      subject.find("cookie1", "www.facebook.com").domain.should eq ".facebook.com"
     end
 
     it "returns the right cookie for every given domain/path" do
-      subject.find("cookie1", "example.org").value.should == "1"
-      subject.find("cookie1", "www.facebook.com").value.should == "3"
-      subject.find("cookie2", "sub1.example.org").value.should == "4"
+      subject.find("cookie1", "example.org").value.should eq "1"
+      subject.find("cookie1", "www.facebook.com").value.should eq "3"
+      subject.find("cookie2", "sub1.example.org").value.should eq "4"
     end
 
     it "does not return a cookie from other domain" do
-      subject.find("cookie2", "www.example.org").should == nil
+      subject.find("cookie2", "www.example.org").should eq nil
     end
 
     it "respects path precedence rules" do
-      subject.find("cookie1", "www.example.org").value.should == "1"
-      subject.find("cookie1", "www.example.org", "/dir1/123").value.should == "2"
+      subject.find("cookie1", "www.example.org").value.should eq "1"
+      subject.find("cookie1", "www.example.org", "/dir1/123").value.should eq "2"
     end
   end
 
   describe "#[]" do
     it "returns the first matching cookie's value" do
-      subject["cookie1", "example.org"].should == "1"
+      subject["cookie1", "example.org"].should eq "1"
     end
 
     it "returns nil if no cookie is found" do
-      subject["notexisting"].should == nil
+      subject["notexisting"].should eq nil
     end
   end
 end
